<?php
/**
 * WooCommerce plugin to display a custom field on product page.
 *
 * Plugin Name: WooCommerce Product Custom Field
 * Plugin URI: https://www.dorzki.io/adding-fields-to-woocommerce-product-pages/?utm_source=wordpress-plugin&utm_medium=plugin-uri&utm_campaign=tutorial-code
 * Description: WooCommerce plugin to display a custom field on product page.
 * Version: 1.0.0
 * Requires at least: 5.0
 * Requires PHP: 7.4
 * Author: dorzki
 * Author URI: https://www.dorzki.io/?utm_source=wordpress-plugin&utm_medium=author-uri&utm_campaign=tutorial-code
 * License: GPL-2.0+
 * License URI: http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain: dorzki-wc-product-custom-field
 *
 * @package    WordPress
 * @subpackage Plugins
 * @author     Dor Zuberi <admin@dorzki.io>
 * @link       https://www.dorzki.io
 * @version    1.0.0
 */

// Block if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Plugin Constants
if ( ! defined( 'DRZK_WC_CUSTOM_FIELD_PATH' ) ) {
	define( 'DRZK_WC_CUSTOM_FIELD_PATH', __DIR__ );
}


/**
 * Enable support for plugin localization and internationalization
 */
function dorzki_register_plugin_i18n() {
	load_plugin_textdomain( 'dorzki-wc-product-custom-field' );
}

add_action( 'plugins_loaded', 'dorzki_register_plugin_i18n' );

/**
 * Checks if WooCommerce is installed and activated
 */
function dorzki_check_required_plugins() {

	if ( ! in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ), true ) ) {
		add_action( 'admin_notices', 'dorzki_display_woocommerce_notice' );

		return;
	}

	include_once DRZK_WC_CUSTOM_FIELD_PATH . '/class-plugin.php';
}

add_action( 'plugins_loaded', 'dorzki_check_required_plugins' );

/**
 * Displays an admin notice for WooCommerce
 */
function dorzki_display_woocommerce_notice() {

	$notice = sprintf(
	/* translators: 1: WooCommerce 2: Plugin Name */
		esc_html__( '"%1$s" is required to be installed and activated order to use "%2$s".', 'dorzki-wc-product-custom-field' ),
		'<strong>' . esc_html__( 'WooCommerce', 'dorzki-wc-product-custom-field' ) . '</strong>',
		'<strong>' . esc_html__( 'WooCommerce Product Custom Field', 'dorzki-wc-product-custom-field' ) . '</strong>'
	);

	echo wp_kses_post( "<div class='notice notice-error'><p>{$notice}</p></div>" );
}
